==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebActiveStepChangingArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActiveStepChangingArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActiveStepChangingArgsDetailDescription, _super);
    function WebActiveStepChangingArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = 0;
        _this.g = 0;
        return _this;
    }
    WebActiveStepChangingArgsDetailDescription.prototype.get_type = function () {
        return "WebActiveStepChangingArgsDetail";
    };
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "oldIndex", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("OldIndex");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "newIndex", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("NewIndex");
        },
        enumerable: true,
        configurable: true
    });
    WebActiveStepChangingArgsDetailDescription.$t = markType(WebActiveStepChangingArgsDetailDescription, 'WebActiveStepChangingArgsDetailDescription', Description.$);
    WebActiveStepChangingArgsDetailDescription.__marshalByValue = true;
    WebActiveStepChangingArgsDetailDescription.__marshalByValueAlias = "ActiveStepChangingArgsDetail";
    return WebActiveStepChangingArgsDetailDescription;
}(Description));
export { WebActiveStepChangingArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebActiveStepChangingArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebActiveStepChangingArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangingArgsDetailDescription, _super);
    function WebActiveStepChangingArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.j = 0;
        _this.i = 0;
        return _this;
    }
    WebActiveStepChangingArgsDetailDescription.prototype.get_type = function () {
        return "WebActiveStepChangingArgsDetail";
    };
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "oldIndex", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("OldIndex");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebActiveStepChangingArgsDetailDescription.prototype, "newIndex", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("NewIndex");
        },
        enumerable: false,
        configurable: true
    });
    WebActiveStepChangingArgsDetailDescription.$t = markType(WebActiveStepChangingArgsDetailDescription, 'WebActiveStepChangingArgsDetailDescription', Description.$);
    WebActiveStepChangingArgsDetailDescription.__marshalByValue = true;
    WebActiveStepChangingArgsDetailDescription.__marshalByValueAlias = "ActiveStepChangingArgsDetail";
    return WebActiveStepChangingArgsDetailDescription;
}(Description));
export { WebActiveStepChangingArgsDetailDescription };
